import type { ActionCreator, Reducer } from 'redux';
import type { SavedQueryAggregationThunkAction } from '.';
import type { Item } from './aggregations-queries-items';
export type Status = 'initial' | 'fetching' | 'error' | 'ready';
export type State = {
    isModalOpen: boolean;
    selectedItem: Item | null;
    createCollectionStatus: Status;
    databases: string[];
    selectedDatabase: string | null;
    databasesStatus: Status;
    collections: string[];
    selectedCollection: string | null;
    collectionsStatus: Status;
    updateItemNamespace: boolean;
};
export declare enum ActionTypes {
    OpenModal = "compass-saved-aggregations-queries/openModal",
    CloseModal = "compass-saved-aggregations-queries/closeModal",
    CreateNamespaceStatusChange = "compass-saved-aggregations-queries/createNamespaceStatusChange",
    SelectDatabase = "compass-saved-aggregations-queries/selectDatabase",
    LoadDatabases = "compass-saved-aggregations-queries/loadDatabases",
    LoadDatabasesSuccess = "compass-saved-aggregations-queries/loadDatabasesSuccess",
    LoadDatabasesError = "compass-saved-aggregations-queries/loadDatabasesError",
    SelectCollection = "compass-saved-aggregations-queries/selectCollection",
    LoadCollections = "compass-saved-aggregations-queries/loadCollections",
    LoadCollectionsSuccess = "compass-saved-aggregations-queries/loadCollectionsSuccess",
    LoadCollectionsError = "compass-saved-aggregations-queries/loadCollectionsError",
    UpdateNamespaceChecked = "compass-saved-aggregations-queries/updateNamespaceChecked"
}
type OpenModalAction = {
    type: ActionTypes.OpenModal;
    selectedItem: Item;
};
type CloseModalAction = {
    type: ActionTypes.CloseModal;
};
type CreateNamespaceStatusChangeAction = {
    type: ActionTypes.CreateNamespaceStatusChange;
    status: Status;
};
type SelectDatabaseAction = {
    type: ActionTypes.SelectDatabase;
    database: string;
};
type LoadDatabasesAction = {
    type: ActionTypes.LoadDatabases;
};
type LoadDatabasesSuccessAction = {
    type: ActionTypes.LoadDatabasesSuccess;
    databases: string[];
};
type LoadDatabasesErrorAction = {
    type: ActionTypes.LoadDatabasesError;
};
type SelectCollectionAction = {
    type: ActionTypes.SelectCollection;
    collection: string;
};
type LoadCollectionsAction = {
    type: ActionTypes.LoadCollections;
};
type LoadCollectionsSuccessAction = {
    type: ActionTypes.LoadCollectionsSuccess;
    collections: string[];
};
type LoadCollectionsErrorAction = {
    type: ActionTypes.LoadCollectionsError;
};
type UpdateNamespaceChecked = {
    type: ActionTypes.UpdateNamespaceChecked;
    updateItemNamespace: boolean;
};
export type Actions = OpenModalAction | CloseModalAction | CreateNamespaceStatusChangeAction | SelectDatabaseAction | LoadDatabasesAction | LoadDatabasesErrorAction | LoadDatabasesSuccessAction | SelectCollectionAction | LoadCollectionsAction | LoadCollectionsErrorAction | LoadCollectionsSuccessAction | UpdateNamespaceChecked;
declare const reducer: Reducer<State>;
export declare const updateItemNamespaceChecked: (updateItemNamespace: boolean) => {
    type: ActionTypes;
    updateItemNamespace: boolean;
};
export declare const closeModal: ActionCreator<CloseModalAction>;
export declare const openSavedItem: (id: string) => SavedQueryAggregationThunkAction<Promise<void>>;
export declare const updateNamespaceChecked: (updateNamespaceChecked: boolean) => SavedQueryAggregationThunkAction<void>;
export declare const openSelectedItem: () => SavedQueryAggregationThunkAction<Promise<void>>;
export declare const selectDatabase: (database: string) => SavedQueryAggregationThunkAction<Promise<void>>;
export declare const selectCollection: ActionCreator<SelectCollectionAction>;
export default reducer;
//# sourceMappingURL=open-item.d.ts.map